CompletionEvent class

Event emitted when a completion finishes or fails

Constructors

CompletionEvent(String promptId, bool success, [String? errorDetails])

Properties

errorDetails String?
final
hashCode int
The hash code for this object.
no setterinherited
promptId String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
success bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited