LlamaChild class

Child isolate that handles Llama model operations

Constructors

LlamaChild()

Properties

hashCode int
The hash code for this object.
no setterinherited
id Object
A unique identifier for this child to identify itself to the parent.
finalinherited
llama Llama?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shouldStop bool
getter/setter pair
stream Stream<LlamaCommand>
A broadcast stream of all messages from the parent.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onData(LlamaCommand data) → void
A callback to run when new data is received from the parent.
onSpawn() Future<void>
Runs when the child isolate is spawned, after registerWithParent is called.
inherited
registerWithParent(TypedSendPort<ChildIsolatePayload<LlamaResponse, LlamaCommand>> port) Future<void>
Registers this child with its parent.
inherited
sendToParent(LlamaResponse obj) → void
Sends data to the parent isolate.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited