LlamaLoad class

Inheritance

Constructors

LlamaLoad({required String path, required ModelParams modelParams, required ContextParams contextParams, required SamplerParams samplingParams, bool verbose = false, String? mmprojPath})

Properties

contextParams ContextParams
final
hashCode int
The hash code for this object.
no setterinherited
mmprojPath String?
final
modelParams ModelParams
final
path String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
samplingParams SamplerParams
final
verbose bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited