LlamaParent class

Parent class that manages communication with the LlamaChild isolate

Constructors

LlamaParent(LlamaLoad loadCommand, [PromptFormat? formatter])

Properties

completions Stream<CompletionEvent>
no setter
formatter PromptFormat?
final
hashCode int
The hash code for this object.
no setterinherited
isGenerating bool
Whether text generation is in progress
no setter
loadCommand LlamaLoad
final
messages List<Map<String, dynamic>>
List of messages for chat history used by the formatter
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status LlamaStatus
no setter
stream Stream<String>
Stream of text generated by the model
no setter

Methods

cancelScope(Object scope, {bool cancelInFlight = true, bool cancelQueued = true}) Future<void>
dispose() Future<void>
disposeScope(LlamaScope scope) Future<void>
Requests the child to free the C++ slot associated with this scope.
getEmbeddings(String prompt) Future<List<double>>
getScope() → dynamic
init() Future<void>
loadSession(LlamaScope scope, String path) Future<void>
Requests the child to load a Disk session into a VRAM slot.
loadState(LlamaScope scope, Uint8List data) Future<void>
Requests the child to load RAM state into a VRAM slot.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
saveState(LlamaScope scope) Future<Uint8List>
Requests the child to save the VRAM state of a specific scope to RAM.
sendPrompt(String prompt, {Object? scope}) Future<String>
sendPromptWithImages(String prompt, List<LlamaImage> images, {Object? scope}) Future<String>
stop() Future<void>
toString() String
A string representation of this object.
inherited
waitForCompletion(String promptId) Future<void>

Operators

operator ==(Object other) bool
The equality operator.
inherited