LlamaPoolingType enum
Values
- unspecified → const LlamaPoolingType
-
const LlamaPoolingType(-1) - none → const LlamaPoolingType
-
const LlamaPoolingType(0) - mean → const LlamaPoolingType
-
const LlamaPoolingType(1) - cls → const LlamaPoolingType
-
const LlamaPoolingType(2) - last → const LlamaPoolingType
-
const LlamaPoolingType(3) - rank → const LlamaPoolingType
-
const LlamaPoolingType(4)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
LlamaPoolingType> - A constant List of the values in this enum, in order of their declaration.