LlamaPrompt class

Inheritance

Constructors

LlamaPrompt(String prompt, String promptId, {List<LlamaImage>? images, String? slotId})

Properties

hashCode int
The hash code for this object.
no setterinherited
images List<LlamaImage>?
final
prompt String
final
promptId String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
slotId String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited