LlamaResponse class

Constructors

LlamaResponse({required String text, required bool isDone, LlamaStatus? status, String? promptId, String? errorDetails, bool isConfirmation = false, List<double>? embeddings, Uint8List? stateData})
LlamaResponse.confirmation(LlamaStatus status, [String? promptId])
factory
LlamaResponse.error(String errorMessage, [String? promptId])
factory
LlamaResponse.stateData(Uint8List data)
factory

Properties

embeddings List<double>?
final
errorDetails String?
final
hashCode int
The hash code for this object.
no setterinherited
isConfirmation bool
final
isDone bool
final
promptId String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stateData Uint8List?
final
status LlamaStatus?
final
text String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited