MCPClient class

Clean MCP client that handles all the protocol stuff

Constructors

MCPClient()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tools List<Tool>
final

Methods

callTool(String name, [Map<String, dynamic>? args]) Future<String>
Call a tool by name
connect({String host = '127.0.0.1', int port = 4242}) Future<void>
Connect and initialize
dispose() → void
findTool(String keyword) Tool?
Find tool by keyword
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited