MCPServer class

Constructors

MCPServer()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

add(MCPServerTool tool) → void
handleForTcp(Map<String, dynamic> req) Future<Map<String, dynamic>>
Public handler you can call from any transport (TCP, stdio, etc.) This is what your TCP server should call.
listenStdio() Future<void>
STDIO server (optional)
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited