MCPServerTool class abstract

An MCP tool. Implementations must return content parts per MCP: e.g. {'type':'text','text':'hello'}

Constructors

MCPServerTool()

Properties

description String
no setter
hashCode int
The hash code for this object.
no setterinherited
inputSchema Map<String, dynamic>
JSON Schema for the tool's input
no setter
name String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

call(Map<String, dynamic> args) Future<List<Map<String, dynamic>>>
Execute the tool and return a list of MCP content parts.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited