KvOverride class final
Override for a single GGUF metadata key. Used to patch model metadata at load time without re-quantizing the file.
Constructors
- KvOverride.bool(String key, bool value)
-
factory
- KvOverride.float(String key, double value)
-
factory
-
KvOverride.fromJson(Map<
String, Object?> json) -
factory
- KvOverride.int(String key, int value)
-
factory
- KvOverride.string(String key, String value)
-
factory
Properties
- boolValue → bool?
-
final
- floatValue → double?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- intValue → int?
-
final
- key → String
-
Metadata key (max 127 chars; longer values are truncated).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringValue → String?
-
final
- type → KvOverrideType
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited